==> ejc-sddjsorg-impl-3.0.0-20211103.074650-137-sources.jar: com/ejianc/business/production/bean/TransferorEntity.java <==
package com.ejianc.business.production.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-受让方
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_transferor")
public class TransferorEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="transferor_name")
    private String transferorName; // 受让方名称
    @TableField(value="transferor_name_id")
    private Long transferorNameId;
    @TableField(value="unified_social_credit_code")
    private String unifiedSocialCreditCode; // 统一社会信用代码
    @TableField(value="org_nature")
    private String orgNature; // 企业性质
    @TableField(value="acceptance_date")
    private java.util.Date acceptanceDate; // 受理时间
    @TableField(value="holding_ratio")
    private java.math.BigDecimal holdingRatio; // 受让方持有比例
    @TableField(value="deal_price")
    private java.math.BigDecimal dealPrice; //成交价格
    @TableField(value="deal_price_big")
    private String dealPriceBig; // 成交价格(大写)
    @TableField(value="audit")
    private java.math.BigDecimal audit; // 审计值
    @TableField(value="audit_big")
    private String auditBig; // 审计值(大写)
    @TableField(value="pid")
    private Long pid; // 父类id

    public String getTransferorName() {
        return transferorName;
    }

    public void setTransferorName(String transferorName) {
        this.transferorName = transferorName;
    }

    /**
     * 统一社会信用代码
     */
    public String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnifiedSocialCreditCode(String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 企业性质
     */
    public String getOrgNature() {
        return orgNature;
    }

    /**
     * 企业性质
     */
    public void setOrgNature(String orgNature) {
        this.orgNature = orgNature;
    }
    /**
     * 受理时间
     */
    public java.util.Date getAcceptanceDate() {
        return acceptanceDate;
    }

    /**
     * 受理时间
     */
    public void setAcceptanceDate(java.util.Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    /**
     * 父类id
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 父类id
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getTransferorNameId() {
        return transferorNameId;
    }

    public void setTransferorNameId(Long transferorNameId) {
        this.transferorNameId = transferorNameId;
    }

    public BigDecimal getHoldingRatio() {
        return holdingRatio;
    }

    public void setHoldingRatio(BigDecimal holdingRatio) {
        this.holdingRatio = holdingRatio;
    }

    public BigDecimal getDealPrice() {
        return dealPrice;
    }

    public void setDealPrice(BigDecimal dealPrice) {
        this.dealPrice = dealPrice;
    }

    public String getDealPriceBig() {
        return dealPriceBig;
    }

    public void setDealPriceBig(String dealPriceBig) {
        this.dealPriceBig = dealPriceBig;
    }

    public BigDecimal getAudit() {
        return audit;
    }

    public void setAudit(BigDecimal audit) {
        this.audit = audit;
    }

    public String getAuditBig() {
        return auditBig;
    }

    public void setAuditBig(String auditBig) {
        this.auditBig = auditBig;
    }
}

==> ejc-sddjsorg-impl-3.0.0-20211104.063347-142-sources.jar: com/ejianc/business/production/bean/TransferorEntity.java <==
package com.ejianc.business.production.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-受让方
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_transferor")
public class TransferorEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="transferor_name")
    private String transferorName; // 受让方名称
    @TableField(value="transferor_name_id")
    private Long transferorNameId;
    @TableField(value="unified_social_credit_code")
    private String unifiedSocialCreditCode; // 统一社会信用代码
    @TableField(value="org_nature")
    private String orgNature; // 企业性质
    @TableField(value="acceptance_date")
    private java.util.Date acceptanceDate; // 受理时间
    @TableField(value="holding_ratio")
    private java.math.BigDecimal holdingRatio; // 受让方持有比例
    @TableField(value="deal_price")
    private java.math.BigDecimal dealPrice; //成交价格
    @TableField(value="deal_price_big")
    private String dealPriceBig; // 成交价格(大写)
    @TableField(value="audit")
    private java.math.BigDecimal audit; // 审计值
    @TableField(value="audit_big")
    private String auditBig; // 审计值(大写)
    @TableField(value="transferor_nature")
    private String transferorNature;// 受让性质

    @TableField(value="pid")
    private Long pid; // 父类id

    public String getTransferorName() {
        return transferorName;
    }

    public void setTransferorName(String transferorName) {
        this.transferorName = transferorName;
    }

    /**
     * 统一社会信用代码
     */
    public String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnifiedSocialCreditCode(String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 企业性质
     */
    public String getOrgNature() {
        return orgNature;
    }

    /**
     * 企业性质
     */
    public void setOrgNature(String orgNature) {
        this.orgNature = orgNature;
    }
    /**
     * 受理时间
     */
    public java.util.Date getAcceptanceDate() {
        return acceptanceDate;
    }

    /**
     * 受理时间
     */
    public void setAcceptanceDate(java.util.Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    /**
     * 父类id
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 父类id
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getTransferorNameId() {
        return transferorNameId;
    }

    public void setTransferorNameId(Long transferorNameId) {
        this.transferorNameId = transferorNameId;
    }

    public BigDecimal getHoldingRatio() {
        return holdingRatio;
    }

    public void setHoldingRatio(BigDecimal holdingRatio) {
        this.holdingRatio = holdingRatio;
    }

    public BigDecimal getDealPrice() {
        return dealPrice;
    }

    public void setDealPrice(BigDecimal dealPrice) {
        this.dealPrice = dealPrice;
    }

    public String getDealPriceBig() {
        return dealPriceBig;
    }

    public void setDealPriceBig(String dealPriceBig) {
        this.dealPriceBig = dealPriceBig;
    }

    public BigDecimal getAudit() {
        return audit;
    }

    public void setAudit(BigDecimal audit) {
        this.audit = audit;
    }

    public String getAuditBig() {
        return auditBig;
    }

    public void setAuditBig(String auditBig) {
        this.auditBig = auditBig;
    }

    public String getTransferorNature() {
        return transferorNature;
    }

    public void setTransferorNature(String transferorNature) {
        this.transferorNature = transferorNature;
    }
}
